@@ -1,8 +1,6 @@
 //!
 //! Runs the roast
 //!
-extern crate chrono;
-extern crate uuid;
 
 use freeroast::roast::new_roast::*;
 use std::io;
@@ -45,7 +43,7 @@ fn main() -> Result<()> {
     bean.get(db_file).unwrap();
 
     // Create new roast instance
-    let mut new_roast = &mut Roast::new(bean.to_owned());
+    let mut new_roast = Roast::new(bean.to_owned());
 
     // Remove
     println!("bean id: {}", bean.id);
@@ -67,7 +65,7 @@ fn main() -> Result<()> {
     println!("Press ENTER when you put beans in ");
     stdin.read_line(&mut buff)?;
     check_buff(buff.to_string());
-    handle_roast_event(RoastEvent::BeansIn(), new_roast.to_owned())?;
+    RoastEvent::BeansIn().handle(&mut new_roast)?;
 
     // Clear buff
     String::clear(&mut buff);
@@ -75,7 +73,7 @@ fn main() -> Result<()> {
     println!("Press ENTER when first crack starts");
     stdin.read_line(&mut buff)?;
     check_buff(buff.to_string());
-    handle_roast_event(RoastEvent::FirstCrackStart(), new_roast.to_owned())?;
+    RoastEvent::FirstCrackStart().handle(&mut new_roast)?;
 
     // Clear buff
     String::clear(&mut buff);
@@ -84,7 +82,7 @@ fn main() -> Result<()> {
     println!("Press ENTER when first crack is done");
     io::stdin().read_line(&mut buff)?;
     check_buff(buff.to_string());
-    handle_roast_event(RoastEvent::FirstCrackEnd(), new_roast.to_owned())?;
+    RoastEvent::FirstCrackEnd().handle(&mut new_roast)?;
 
     // Clear buff
     String::clear(&mut buff);
@@ -93,13 +91,13 @@ fn main() -> Result<()> {
     println!("Enter \"s\" if going to second crack. Press any other key to end roast");
     stdin.read_line(buff)?;
     if buff.eq(&mut "s\n") {
-        new_roast.second_crack_start = Some(time_now());
-        new_roast.second_crack_finish = Some(time_now());
         String::clear(&mut buff);
         println!("Press ENTER when second crack starts ");
         io::stdin().read_line(buff)?;
         check_buff(buff.to_string());
-        handle_roast_event(RoastEvent::SecondCrackStart(), new_roast.to_owned())?;
+        new_roast.second_crack_start = Some(time_now());
+        new_roast.second_crack_finish = Some(time_now());
+        RoastEvent::SecondCrackStart().handle(&mut new_roast)?;
         String::clear(&mut buff);
 
         println!(
@@ -107,21 +105,18 @@ fn main() -> Result<()> {
         );
         io::stdin().read_line(buff)?;
         if buff.eq(&mut "s\n") {
-            handle_roast_event(RoastEvent::SecondCrackEnd(), new_roast.to_owned())?;
+            RoastEvent::SecondCrackEnd().handle(&mut new_roast)?;
             String::clear(&mut buff);
             println!("Press ENTER to end roast");
             stdin.read_line(buff)?;
             check_buff(buff.to_string());
-            handle_roast_event(RoastEvent::EndRoast(), new_roast.to_owned())?;
-            new_roast.insert(db_file).unwrap();
+            RoastEvent::EndRoast().handle(&mut new_roast)?;
         } else {
-            handle_roast_event(RoastEvent::SecondCrackEnd(), new_roast.to_owned())?;
-            new_roast.insert(db_file).unwrap();
-            handle_roast_event(RoastEvent::EndRoast(), new_roast.to_owned())?;
+            RoastEvent::SecondCrackEnd().handle(&mut new_roast)?;
+            RoastEvent::EndRoast().handle(&mut new_roast)?;
         }
     } else {
-        new_roast.insert(db_file).unwrap();
-        handle_roast_event(RoastEvent::EndRoast(), new_roast.to_owned())?;
+        RoastEvent::EndRoast().handle(&mut new_roast)?;
     }
 
     Ok(())
