@@ -1,9 +1,6 @@
-extern crate chrono;
-extern crate rusqlite;
-
 pub use super::beans::*;
 use chrono::NaiveDateTime;
-use rusqlite::{params, Connection, Result, ToSql};
+use rusqlite::{params, Connection, Result};
 use uuid::Uuid;
 
 ///
@@ -73,7 +70,7 @@ impl Roast {
             self.starting_weight,
             self.beans_in.timestamp(),
             self.first_crack_start.timestamp(),
-            self.first_crack_finish.timestamp().to_sql().unwrap(),
+            self.first_crack_finish.timestamp(),
             match self.second_crack_start {
                 Some(scs) => {
                     Some(scs.timestamp())
@@ -86,7 +83,7 @@ impl Roast {
                 }
                 None => None,
             },
-            self.beans_out.timestamp().to_sql().unwrap(),
+            self.beans_out.timestamp(),
         ])?;
 
         qry.finalize()?;
